@@ -20,12 +20,13 @@
  * Author: Alexander Larsson <alexl@redhat.com>
  */
 
-#include <config.h>
+#include "config.h"
 #include <string.h>
 
 #include "gfilemonitor.h"
 #include "gio-marshal.h"
 #include "gioenumtypes.h"
+#include "gfile.h"
 #include "gvfs.h"
 #include "glibintl.h"
 
@@ -52,6 +53,9 @@ enum {
   LAST_SIGNAL
 };
 
+/* work around a limitation of the aliasing foo */
+#undef g_file_monitor
+
 G_DEFINE_ABSTRACT_TYPE (GFileMonitor, g_file_monitor, G_TYPE_OBJECT);
 
 typedef struct {
@@ -156,9 +160,8 @@ g_file_monitor_finalize (GObject *object)
     }
 
   g_hash_table_destroy (monitor->priv->rate_limiter);
-  
-  if (G_OBJECT_CLASS (g_file_monitor_parent_class)->finalize)
-    (*G_OBJECT_CLASS (g_file_monitor_parent_class)->finalize) (object);
+
+  G_OBJECT_CLASS (g_file_monitor_parent_class)->finalize (object);
 }
 
 static void
@@ -170,9 +173,8 @@ g_file_monitor_dispose (GObject *object)
 
   /* Make sure we cancel on last unref */
   g_file_monitor_cancel (monitor);
-  
-  if (G_OBJECT_CLASS (g_file_monitor_parent_class)->dispose)
-    (*G_OBJECT_CLASS (g_file_monitor_parent_class)->dispose) (object);
+
+  G_OBJECT_CLASS (g_file_monitor_parent_class)->dispose (object);
 }
 
 static void
@@ -249,9 +251,10 @@ g_file_monitor_init (GFileMonitor *monitor)
 gboolean
 g_file_monitor_is_cancelled (GFileMonitor *monitor)
 {
-  g_return_val_if_fail (G_IS_FILE_MONITOR (monitor), FALSE);
   gboolean res;
 
+  g_return_val_if_fail (G_IS_FILE_MONITOR (monitor), FALSE);
+
   G_LOCK (cancelled);
   res = monitor->priv->cancelled;
   G_UNLOCK (cancelled);
