@@ -20,7 +20,7 @@
  * Author: Alexander Larsson <alexl@redhat.com>
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -53,8 +53,8 @@
 #if defined(HAVE_STATFS) && defined(HAVE_STATVFS)
 /* Some systems have both statfs and statvfs, pick the
    most "native" for these */
-# if defined(sun) && defined(__SVR4)
-   /* on solaris, statfs doesn't even have the
+# if !defined(HAVE_STRUCT_STATFS_F_BAVAIL)
+   /* on solaris and irix, statfs doesn't even have the
       f_bavail field */
 #  define USE_STATVFS
 # else
@@ -72,6 +72,7 @@
 
 #endif
 
+#include "gfileattribute.h"
 #include "glocalfile.h"
 #include "glocalfileinfo.h"
 #include "glocalfileenumerator.h"
@@ -80,6 +81,8 @@
 #include "glocaldirectorymonitor.h"
 #include "glocalfilemonitor.h"
 #include "gmountprivate.h"
+#include "gunixmounts.h"
+#include "gioerror.h"
 #include <glib/gstdio.h>
 #include "glibintl.h"
 
@@ -130,9 +133,8 @@ g_local_file_finalize (GObject *object)
   local = G_LOCAL_FILE (object);
 
   g_free (local->filename);
-  
-  if (G_OBJECT_CLASS (g_local_file_parent_class)->finalize)
-    (*G_OBJECT_CLASS (g_local_file_parent_class)->finalize) (object);
+
+  G_OBJECT_CLASS (g_local_file_parent_class)->finalize (object);
 }
 
 static void
@@ -578,7 +580,7 @@ g_local_file_enumerate_children (GFile                *file,
 				 GError              **error)
 {
   GLocalFile *local = G_LOCAL_FILE (file);
-  return _g_local_file_enumerator_new (local->filename,
+  return _g_local_file_enumerator_new (local,
 				       attributes, flags,
 				       cancellable, error);
 }
@@ -618,6 +620,10 @@ get_fs_type (long f_type)
     {
     case 0xadf5:
       return "adfs";
+    case 0x5346414f:
+      return "afs";
+    case 0x0187:
+      return "autofs";
     case 0xADFF:
       return "affs";
     case 0x42465331:
@@ -808,6 +814,7 @@ is_xp_or_later (void)
 
   if (result == -1)
     {
+#ifndef _MSC_VER    
       OSVERSIONINFOEX ver_info = {0};
       DWORDLONG cond_mask = 0;
       int op = VER_GREATER_EQUAL;
@@ -822,6 +829,9 @@ is_xp_or_later (void)
       result = VerifyVersionInfo (&ver_info,
 				  VER_MAJORVERSION | VER_MINORVERSION, 
 				  cond_mask) != 0;
+#else
+      result = ((DWORD)(LOBYTE (LOWORD (GetVersion ())))) >= 5;  
+#endif
     }
 
   return result;
@@ -912,7 +922,7 @@ g_local_file_query_filesystem_info (GFile         *file,
 {
   GLocalFile *local = G_LOCAL_FILE (file);
   GFileInfo *info;
-  int statfs_result;
+  int statfs_result = 0;
   gboolean no_size;
 #ifndef G_OS_WIN32
   guint64 block_size;
@@ -1047,7 +1057,7 @@ g_local_file_find_enclosing_mount (GFile         *file,
 
   if (g_lstat (local->filename, &buf) != 0)
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
 		      /* Translators: This is an error message when trying to
 		       * find the enclosing (user visible) mount of a file, but
 		       * none exists. */
@@ -1058,7 +1068,7 @@ g_local_file_find_enclosing_mount (GFile         *file,
   mountpoint = find_mountpoint_for (local->filename, buf.st_dev);
   if (mountpoint == NULL)
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
 		      /* Translators: This is an error message when trying to
 		       * find the enclosing (user visible) mount of a file, but
 		       * none exists. */
@@ -1071,7 +1081,7 @@ g_local_file_find_enclosing_mount (GFile         *file,
   if (mount)
     return mount;
 
-  g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
+  g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND,
 		  /* Translators: This is an error message when trying to find
 		   * the enclosing (user visible) mount of a file, but none
 		   * exists. */
@@ -1093,9 +1103,9 @@ g_local_file_set_display_name (GFile         *file,
   parent = g_file_get_parent (file);
   if (parent == NULL)
     {
-      g_set_error (error, G_IO_ERROR,
-		   G_IO_ERROR_FAILED,
-		   _("Can't rename root directory"));
+      g_set_error_literal (error, G_IO_ERROR,
+                           G_IO_ERROR_FAILED,
+                           _("Can't rename root directory"));
       return NULL;
     }
   
@@ -1111,9 +1121,9 @@ g_local_file_set_display_name (GFile         *file,
   if (!(g_lstat (new_local->filename, &statbuf) == -1 &&
 	errno == ENOENT))
     {
-      g_set_error (error, G_IO_ERROR,
-		   G_IO_ERROR_EXISTS,
-		   _("Can't rename file, filename already exist"));
+      g_set_error_literal (error, G_IO_ERROR,
+                           G_IO_ERROR_EXISTS,
+                           _("Can't rename file, filename already exist"));
       return NULL;
     }
 
@@ -1124,9 +1134,9 @@ g_local_file_set_display_name (GFile         *file,
       if (errsv == EINVAL)
 	/* We can't get a rename file into itself error herer,
 	   so this must be an invalid filename, on e.g. FAT */
-	g_set_error (error, G_IO_ERROR,
-		     G_IO_ERROR_INVALID_FILENAME,
-		     _("Invalid filename"));
+	g_set_error_literal (error, G_IO_ERROR,
+                             G_IO_ERROR_INVALID_FILENAME,
+                             _("Invalid filename"));
       else
 	g_set_error (error, G_IO_ERROR,
 		     g_io_error_from_errno (errsv),
@@ -1257,9 +1267,9 @@ g_local_file_read (GFile         *file,
   if (fstat(fd, &buf) == 0 && S_ISDIR (buf.st_mode))
     {
       close (fd);
-      g_set_error (error, G_IO_ERROR,
-		   G_IO_ERROR_IS_DIRECTORY,
-		   _("Can't open directory"));
+      g_set_error_literal (error, G_IO_ERROR,
+                           G_IO_ERROR_IS_DIRECTORY,
+                           _("Can't open directory"));
       return NULL;
     }
   
@@ -1725,9 +1735,9 @@ g_local_file_trash (GFile         *file,
       topdir = find_topdir_for (local->filename);
       if (topdir == NULL)
 	{
-	  g_set_error (error, G_IO_ERROR,
-		       G_IO_ERROR_NOT_SUPPORTED,
-		       _("Unable to find toplevel directory for trash"));
+	  g_set_error_literal (error, G_IO_ERROR,
+                               G_IO_ERROR_NOT_SUPPORTED,
+                               _("Unable to find toplevel directory for trash"));
 	  return FALSE;
 	}
       
@@ -1804,9 +1814,9 @@ g_local_file_trash (GFile         *file,
       if (trashdir == NULL)
 	{
 	  g_free (topdir);
-	  g_set_error (error, G_IO_ERROR,
-		       G_IO_ERROR_NOT_SUPPORTED,
-		       _("Unable to find or create trash directory"));
+	  g_set_error_literal (error, G_IO_ERROR,
+                               G_IO_ERROR_NOT_SUPPORTED,
+                               _("Unable to find or create trash directory"));
 	  return FALSE;
 	}
     }
@@ -1824,9 +1834,9 @@ g_local_file_trash (GFile         *file,
       g_free (topdir);
       g_free (infodir);
       g_free (filesdir);
-      g_set_error (error, G_IO_ERROR,
-		   G_IO_ERROR_NOT_SUPPORTED,
-		   _("Unable to find or create trash directory"));
+      g_set_error_literal (error, G_IO_ERROR,
+                           G_IO_ERROR_NOT_SUPPORTED,
+                           _("Unable to find or create trash directory"));
       return FALSE;
     }  
 
@@ -1988,9 +1998,9 @@ g_local_file_make_directory (GFile         *file,
 
       if (errsv == EINVAL)
 	/* This must be an invalid filename, on e.g. FAT */
-	g_set_error (error, G_IO_ERROR,
-		     G_IO_ERROR_INVALID_FILENAME,
-		     _("Invalid filename"));
+	g_set_error_literal (error, G_IO_ERROR,
+                             G_IO_ERROR_INVALID_FILENAME,
+                             _("Invalid filename"));
       else
 	g_set_error (error, G_IO_ERROR,
 		     g_io_error_from_errno (errsv),
@@ -2017,9 +2027,9 @@ g_local_file_make_symbolic_link (GFile         *file,
 
       if (errsv == EINVAL)
 	/* This must be an invalid filename, on e.g. FAT */
-	g_set_error (error, G_IO_ERROR,
-		     G_IO_ERROR_INVALID_FILENAME,
-		     _("Invalid filename"));
+	g_set_error_literal (error, G_IO_ERROR,
+                             G_IO_ERROR_INVALID_FILENAME,
+                             _("Invalid filename"));
       else
 	g_set_error (error, G_IO_ERROR,
 		     g_io_error_from_errno (errsv),
@@ -2029,7 +2039,7 @@ g_local_file_make_symbolic_link (GFile         *file,
     }
   return TRUE;
 #else
-  g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, "Symlinks not supported");
+  g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, "Symlinks not supported");
   return FALSE;
 #endif
 }
@@ -2045,7 +2055,7 @@ g_local_file_copy (GFile                  *source,
 		   GError                **error)
 {
   /* Fall back to default copy */
-  g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, "Copy not supported");
+  g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, "Copy not supported");
   return FALSE;
 }
 
@@ -2069,7 +2079,7 @@ g_local_file_move (GFile                  *source,
       !G_IS_LOCAL_FILE (destination))
     {
       /* Fall back to default move */
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, "Move not supported");
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED, "Move not supported");
       return FALSE;
     }
   
@@ -2103,24 +2113,24 @@ g_local_file_move (GFile                  *source,
 	  if (S_ISDIR (statbuf.st_mode))
 	    {
 	      if (source_is_dir)
-		g_set_error (error,
-			     G_IO_ERROR,
-			     G_IO_ERROR_WOULD_MERGE,
-			     _("Can't move directory over directory"));
+		g_set_error_literal (error,
+                                     G_IO_ERROR,
+                                     G_IO_ERROR_WOULD_MERGE,
+                                     _("Can't move directory over directory"));
               else
-		g_set_error (error,
-			     G_IO_ERROR,
-			     G_IO_ERROR_IS_DIRECTORY,
-			     _("Can't copy over directory"));
+		g_set_error_literal (error,
+                                     G_IO_ERROR,
+                                     G_IO_ERROR_IS_DIRECTORY,
+                                     _("Can't copy over directory"));
 	      return FALSE;
 	    }
 	}
       else
 	{
-	  g_set_error (error,
-		       G_IO_ERROR,
-		       G_IO_ERROR_EXISTS,
-		       _("Target file exists"));
+	  g_set_error_literal (error,
+                               G_IO_ERROR,
+                               G_IO_ERROR_EXISTS,
+                               _("Target file exists"));
 	  return FALSE;
 	}
     }
@@ -2130,10 +2140,10 @@ g_local_file_move (GFile                  *source,
       backup_name = g_strconcat (local_destination->filename, "~", NULL);
       if (g_rename (local_destination->filename, backup_name) == -1)
 	{
-      	  g_set_error (error,
-		       G_IO_ERROR,
-		       G_IO_ERROR_CANT_CREATE_BACKUP,
-		       _("Backup file creation failed"));
+      	  g_set_error_literal (error,
+                               G_IO_ERROR,
+                               G_IO_ERROR_CANT_CREATE_BACKUP,
+                               _("Backup file creation failed"));
 	  g_free (backup_name);
 	  return FALSE;
 	}
@@ -2164,16 +2174,16 @@ g_local_file_move (GFile                  *source,
 
       if (errsv == EXDEV)
 	/* This will cause the fallback code to run */
-	g_set_error (error, G_IO_ERROR,
-		     G_IO_ERROR_NOT_SUPPORTED,
-		     _("Move between mounts not supported"));
+	g_set_error_literal (error, G_IO_ERROR,
+                             G_IO_ERROR_NOT_SUPPORTED,
+                             _("Move between mounts not supported"));
       else if (errsv == EINVAL)
 	/* This must be an invalid filename, on e.g. FAT, or
 	   we're trying to move the file into itself...
 	   We return invalid filename for both... */
-	g_set_error (error, G_IO_ERROR,
-		     G_IO_ERROR_INVALID_FILENAME,
-		     _("Invalid filename"));
+	g_set_error_literal (error, G_IO_ERROR,
+                             G_IO_ERROR_INVALID_FILENAME,
+                             _("Invalid filename"));
       else
 	g_set_error (error, G_IO_ERROR,
 		     g_io_error_from_errno (errsv),
